unit SampleEdit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, StdCtrls;

type
  TSampleEdit = class(TEdit)
  private
    FMouseIn,
    FFocused:boolean;
    FChangeOnMouseEnter:boolean;
    FChangeOnFocus:boolean;
    FColorNormal:TColor;
    FColorFocus:TColor;
    procedure CMEnter(var Message: TCMEnter); message CM_ENTER;
    procedure CMExit(var Message: TCMExit); message CM_EXIT;
    procedure CMMouseEnter(var Message: TMessage); message CM_MOUSEENTER;
    procedure CMMouseLeave(var Message: TMessage); message CM_MOUSELEAVE;
  protected
    procedure RefreshView;
  public
    constructor Create(AOwner:TComponent); override;
  published
    property ChangeOnMouseEnter :boolean read FChangeOnMouseEnter write FChangeOnMouseEnter;
    property ChangeOnFocus      :boolean read FChangeOnFocus      write FChangeOnFocus;
    property ColorNormal        :TColor  read FColorNormal        write FColorNormal;
    property ColorFocus         :TColor  read FColorFocus         write FColorFocus;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Samples', [TSampleEdit]);
end;

{ TSampleEdit }

procedure TSampleEdit.CMEnter(var Message: TCMEnter);
begin
     FFocused := True;
     RefreshView;
end;

procedure TSampleEdit.CMExit(var Message: TCMExit);
begin
     FFocused := False;
     RefreshView;
end;

procedure TSampleEdit.CMMouseEnter(var Message: TMessage);
begin
     FMouseIn := True;
     RefreshView;
end;

procedure TSampleEdit.CMMouseLeave(var Message: TMessage);
begin
     FMouseIn := False;
     RefreshView;
end;

constructor TSampleEdit.Create(AOwner: TComponent);
begin
     inherited;
     FMouseIn     := False;
     FFocused     := False;
     FColorNormal := clWindow;
     FColorFocus  := clYellow;
     FChangeOnMouseEnter := True;
     FChangeOnFocus      := True;
     RefreshView;
end;

procedure TSampleEdit.RefreshView;
begin
     if (FMouseIn and FChangeOnMouseEnter) or
        (FFocused and FChangeOnFocus)
        then Color := FColorFocus
        else Color := FColorNormal;
end;

end.
